Stan Math Library: stan/math/prim/mat/fun/col.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

col.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_COL_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_COL_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/err/check_column_index.hpp>
6
7 namespace stan {
8 namespace math {
9
21 template <typename T>
22 inline
23 Eigen::Matrix<T, Eigen::Dynamic, 1>
24 col(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& m,
25 size_t j) {
26 stan::math::check_column_index("col", "j", m, j);
27 return m.col(j - 1);
28 }
29
30 }
31 }
32 #endif
stan
Definition: log_sum_exp.hpp:8
check_column_index.hpp
stan::math::col
Eigen::Matrix< T, Eigen::Dynamic, 1 > col(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m, size_t j)
Return the specified column of the specified matrix using start-at-1 indexing.
Definition: col.hpp:24
Eigen.hpp
stan::math::check_column_index
bool check_column_index(const char *function, const char *name, const Eigen::Matrix< T_y, R, C > &y, const size_t i)
Return true if the specified index is a valid column of the matrix.
Definition: check_column_index.hpp:37

[ Stan Home Page ] © 2011–2016, Stan Development Team.